import dayjs from 'dayjs';

function getcolumns(setdrawer) {
  const disabledDateOfDay = (current) => {
    // Can not select days before today and today
    return current && current < dayjs().endOf('day');
  };
  return {
    columns: [
      {
        dataIndex: 'equipmentNo',
        valueType: 'input',
        title: '设备编号',
        key: 'equipmentNo',
        hideInForm: true,
      },
      {
        dataIndex: 'equipmentName',
        valueType: 'input',
        title: '设备名称',
        key: 'equipmentName',
        hideInForm: true,
      },
      {
        dataIndex: 'installPosition',
        valueType: 'input',
        title: '安装部位',
        key: 'installPosition',
        hideInForm: true,
      },
      {
        dataIndex: 'sparePartNo',
        valueType: 'input',
        title: '备件料号',
        key: 'sparePartNo',
        hideInForm: true,
      },
      {
        dataIndex: 'sparePartName',
        valueType: 'input',
        title: '备件名称',
        key: 'sparePartName',
        hideInForm: true,
      },
      {
        dataIndex: 'supplierNo',
        valueType: 'input',
        title: '供应商编号',
        key: 'supplierNo',
        hideInForm: true,
      },
      {
        dataIndex: 'supplierName',
        valueType: 'input',
        title: '供应商名称',
        key: 'supplierName',
        hideInForm: true,
      },
      {
        dataIndex: 'equipmentId',
        valueType: 'select',
        title: '选择设备',
        key: 'equipmentId',
        hideInDescriptions: true,
        hideInSearch: true,
        hideInTable: true,
        mode: 'radio',
        options: {
          path: '/asset/equipment/selection/user/shop',
          params: {},
        },
        formItemProps: {
          rules: [
            {
              required: true,
              message: '此项为必填项',
            },
          ],
        },
      },
      {
        dataIndex: 'lifePieceStandardId',
        valueType: 'select',
        title: '选择部位-寿命件',
        key: 'lifePieceStandardId',
        hideInDescriptions: true,
        hideInSearch: true,
        hideInTable: true,
        mode: 'radio',
        options: {
          path: '/sparepart/lifePieceStandard/querySelectByEquipmentId',
          linkParams: { equipmentId: '' },
        },
        formItemProps: {
          rules: [
            {
              required: true,
              message: '此项为必填项',
            },
          ],
        },
      },
      {
        dataIndex: 'supplierId',
        valueType: 'select',
        title: '选择供应商',
        key: 'supplierId',
        hideInDescriptions: true,
        hideInSearch: true,
        hideInTable: true,
        mode: 'radio',
        options: {
          path: '/sparepart/sparePartSupplier/queryOnSelect',
          params: {},
        },
        formItemProps: {
          rules: [
            {
              required: true,
              message: '此项为必填项',
            },
          ],
        },
      },
      {
        dataIndex: 'installNum',
        valueType: 'digit',
        searchValueType: 'input',
        title: '安装数量',
        key: 'installNum',
        hideInSearch: true,
        hideInTable: false,
        fieldProps: {
          precision: 0,
        },

        formItemProps: {
          rules: [
            {
              required: true,
              message: '此项为必填项',
            },
          ],
        },
      },

      {
        dataIndex: 'nextReplaceDate',
        title: '下次更换日期',
        valueType: 'date',
        key: 'nextReplaceDateList',
        fieldProps: {
          disabledDate: disabledDateOfDay,
        },
        searchValueType: 'dateRange',
        hideInSearch: false,
        hideInTable: false,
        formItemProps: {
          rules: [
            {
              required: true,
              message: '此项为必填项',
            },
          ],
        },
        render: (text, row, _, action) => {
          return (
            <span
              style={{
                color: `${
                  dayjs(row.nextReplaceDate).valueOf() <
                  dayjs(dayjs().format('YYYY-MM-DD')).valueOf()
                    ? '#f50'
                    : 'rgba(0, 0, 0, 0.85)'
                }`,
              }}
            >
              {row.nextReplaceDate}
            </span>
          );
        },
      },
    ],
    pathconfig: {
      enableadd: true,
      enableedit: true,
      enabledelete: true,
      enabledetail: false,
      add: '/sparepart/lifePieceAccount/initialization',
      edit: '/sparepart/lifePieceAccount/initialization',
      list: '/sparepart/lifePieceAccount/queryList',
      delete: '/sparepart/lifePieceAccount/deleteById',
      detail: '',
    },
  };
}
export default getcolumns;
