/* 寿命件预警
 * @Author: Li Hanlin
 * @Date: 2023-02-17 13:36:11
 * @Last Modified by: Li Hanlin
 * @Last Modified time: 2023-02-17 13:50:04
 */

import * as React from 'react';
import { useState, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import getcolumns from './columns';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import InitForm from '@/components/InitForm';
function Warning(props) {
  const actionRef = useRef(),
    formRef = useRef();
  const [drawer, setdrawer] = useState({
    open: false,
  });
  const pathconfig = useMemo(() => {
    let pathconf = getcolumns(setdrawer)?.pathconfig ?? {};
    return pathconf;
  }, []);
  const { run, loading } = useRequest(doFetch, {
    manual: true,
    onSuccess: (res, params) => {
      if (res?.code == '0000') {
        actionRef?.current?.reload();
        setdrawer((s) => ({
          ...s,
          open: false,
        }));
      }
    },
  });
  const changeColumns = useMemo(() => {
    const columns = [
      {
        title: '线边库',
        dataIndex: 'sparePartNo',
        key: 'sparePartNo',
        editable: false,
      },
      {
        title: '备件料号',
        dataIndex: 'sparePartName',
        key: 'sparePartName',
        span: 3,
        editable: false,
      },
      {
        title: '备件名称',
        dataIndex: 'sparePartName',
        key: 'sparePartName',
        span: 3,
        editable: false,
      },
      {
        title: '供应商编号',
        dataIndex: 'sparePartName',
        key: 'sparePartName',
        span: 3,
        editable: false,
      },
      {
        title: '供应商名称',
        dataIndex: 'sparePartName',
        key: 'sparePartName',
        span: 3,
        editable: false,
      },
      {
        title: '可用数量',
        dataIndex: 'sparePartName',
        key: 'sparePartName',
        search: false,
        span: 3,
        editable: false,
      },
      {
        title: (
          <div>
            更换数量 <span style={{ color: 'red' }}>* </span>
          </div>
        ),
        search: false,
        dataIndex: 'sparePartName',
        key: 'sparePartName',
        span: 3,
        hideInForm: true,
      },
    ];
    return [
      {
        title: (
          <div>
            <span style={{ color: 'red' }}>* </span> 持有寿命件信息
          </div>
        ),
        valueType: 'split',
      },
      {
        dataIndex: 'supplierList',
        key: 'supplierList',
        valueType: 'formSelectList',
        colProps: {
          span: 24,
        },
        span: 3,
        columns,
        hideInSearch: true,
        hideInTable: true,
        path: '/sparepart/sparePartSupplier/queryList',
        params: { status: 1 },
        rowName: 'supplierList',
      },
    ];
  });
  const detail = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          type: 'link',
          onClick: () => {
            setdrawer((s) => ({
              ...s,
              open: true,
              item: row,
              title: '详情',
              val: 'detail',
              title: '详细信息',
            }));
          },
        }}
      >
        详情
      </PremButton>
    );
  };

  const edit = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          onClick: () => {
            setdrawer((s) => ({
              ...s,
              open: true,
              item: row,
              title: '更换寿命件',
              val: 'detailaddon',
            }));
          },
        }}
      >
        更换寿命件
      </PremButton>
    );
  };

  const remove = (text, row, _, action) => {
    return (
      <PremButton
        pop={{
          title: '是否删除?',
          okText: '确认',
          cancelText: '取消',
          onConfirm: () => {
            run({ url: pathconfig?.delete || '/delete', params: { id: row?.id } });
          },
        }}
        btn={{
          size: 'small',
          type: 'danger',
        }}
      >
        删除
      </PremButton>
    );
  };

  const columns = useMemo(() => {
    let defcolumn = getcolumns(setdrawer)?.columns;
    return defcolumn.concat({
      title: '操作',
      valueType: 'option',
      width: 150,
      render: (text, row, _, action) => [pathconfig?.enableedit && edit(text, row, _, action)],
    });
  }, []);

  return (
    <div style={{ position: 'relative' }}>
      <AutoTable
        pagetitle={<h3 className="page-title">寿命件预警</h3>}
        columns={columns}
        actionRef={actionRef}
        path={pathconfig?.list || '/ngic-auth/sysUser/query/page'}
        pageextra={pathconfig?.enableadd ? 'add' : null}
        resizeable={false}
        addconfig={{
          // access: 'sysDepartment_save',
          btn: {
            disabled: false,
            onClick: () => {
              setdrawer((s) => ({
                ...s,
                open: true,
                item: null,
                title: '新增',
                val: 'add',
              }));
            },
          },
        }}
      />

      <DrawerPro
        fields={columns}
        params={{ id: drawer?.item?.id }}
        formRef={formRef}
        placement="right"
        detailpath={pathconfig?.detail || null}
        detailData={drawer?.item}
        defaultFormValue={drawer?.item}
        onClose={() => {
          setdrawer((s) => ({
            ...s,
            open: false,
          }));
        }}
        {...drawer}
        onFinish={(vals) => {
          if (drawer?.val == 'add') {
            run({ url: pathconfig?.add || '/add', params: { ...vals } });
          } else if (drawer?.val == 'edit') {
            run({ url: pathconfig?.edit || '/edit', params: { ...vals, id: drawer?.item?.id } });
          }
        }}
      >
        <InitForm fields={changeColumns} />
      </DrawerPro>
    </div>
  );
}

export default Warning;
